@@ -1,4 +1,4 @@
-from ..utils import Utils, Driver, By
+from ..util import Util, Driver, By
 
 
 class Parser:
@@ -10,8 +10,8 @@ class Parser:
         driver = Driver()
         url = f"http://www.codechef.com/problems/{args[0]}"
         driver.get(url)
-        Utils.wait_until(driver, By.CSS_SELECTOR, "pre")
+        Util.wait_until(driver, By.CSS_SELECTOR, "pre")
 
-        sample = Utils.get_sample(driver)
-        result = Utils.tag_sens(sample)
-        Utils.write_samples(result)
+        sample = Util.get_sample(driver)
+        result = Util.tag_sens(sample)
+        Util.write_samples(result)
